/*
 * Copyright 2008 Kyoto University and Honda Motor Co.,Ltd.
 * All rights reserved.
 * HARK was developed by researchers in Okuno Laboratory
 * at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
 */


/*
 * BandUtils.hpp
 *
 *  Created on: 2011/01/14
 *      Author: HARK Development Team
 */

#ifndef BANDUTILS_HPP_
#define BANDUTILS_HPP_

#include <vector>
#include <utility>
#include <boost/shared_ptr.hpp>
#include <BandAndHarmonicRatio.hpp>

namespace NSHarkBinaural
{

class BandUtils
{
public:
    typedef std::vector<BandAndHarmonicRatio> BandHarmonicVector;
    typedef boost::shared_ptr<BandHarmonicVector> BandHarmonicVectorPtr;

    /**
     * 与えられた周波数バンドでバンド配列を分割する.
     * 与えられた周波数バンドが持つ周波数以下のバンドと、それ以外のバンドに切り分け、返す。
     * @param bands 切り分けるバンド配列（周波数の昇順）
     * @param border 切り分ける境目を表すバンド
     * @return 分割された配列。firstに低周波数側が、secondに高周波数側が格納される（周波数の昇順）。
     */
    static std::pair<BandHarmonicVectorPtr, BandHarmonicVectorPtr>
    DivideBands(const BandHarmonicVector& bands, Band border);
};

}

#endif /* BANDUTILS_HPP_ */
