/*
 * Copyright 2008 Kyoto University and Honda Motor Co.,Ltd.
 * All rights reserved.
 * HARK was developed by researchers in Okuno Laboratory
 * at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
 */


#ifndef DIMPRO_VELOCITY1_HPP_
#define DIMPRO_VELOCITY1_HPP_

#include "scalar.hpp"

namespace NSDimensionPromise
{

/**
 * Velocity1の次元定義.
 */
template <typename T>
struct Velocity1BaseTraits
{
    typedef ScalarNumber<T, 1, 0, -1, 0, 0, 0, 0> ScalarType;
};

/**
 * Velocity1を表すベースクラス.
 */
template <typename T>
class Velocity1Base : public Velocity1BaseTraits<T>::ScalarType
{
public:
    /**
     * Velocity1を表すスカラー変数を生成する.
     * @param meterPerSecond 変数の初期値
     */
    explicit Velocity1Base(const T& meterPerSecond = T())
        : Velocity1BaseTraits<T>::ScalarType(meterPerSecond)
    {  }

    /**
     * Velocity1を表すスカラー変数をコピーして生成する.
     * @param rhs コピー元の変数
     */
    Velocity1Base(const typename Velocity1BaseTraits<T>::ScalarType& rhs)
        : Velocity1BaseTraits<T>::ScalarType(rhs)
    {  }

    /**
      * メートル毎秒単位の値を得る.
      * @return メートル毎秒
      */
    const T& ToMeterPerSecond() const
    {
        return this->X();
    }

    /**
      * メートル毎秒からVelocity1を表すスカラー変数を生成する.
      * @param meterPerSecond メートル毎秒
      * @return Velocity1を表すスカラー変数
      */
    static Velocity1Base FromMeterPerSecond(const T& meterPerSecond)
    {
        return Velocity1Base(meterPerSecond);
    }
};

/**
 * よく使うVelocity1の型.
 */
typedef Velocity1Base<NormalValueType> Velocity1;

}

#endif /* DIMPRO_VELOCITY1_HPP_ */
