/*
 * Copyright 2008 Kyoto University and Honda Motor Co.,Ltd.
 * All rights reserved.
 * HARK was developed by researchers in Okuno Laboratory
 * at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
 */


/*
 * Cluster.cpp
 *
 *  Created on: 2010/12/16
 *      Author: HARK Development Team
 */

#include <Cluster.hpp>
using namespace std;
using namespace boost;

namespace NSHarkBinaural
{

//Logger& Cluster::logger = Logger::GetLogger(Logger::GLOBAL_LOGGER_NAME);

Cluster::Cluster()
    : bandAndPowerList()
{
}

Cluster::Cluster(Band band, double power)
    : bandAndPowerList()
{
    this->bandAndPowerList.push_back(BandAndPower(band, power));
}

void Cluster::Merge(const Cluster& cluster)
{
    static Logger& logger = Logger::GetLogger(Logger::GLOBAL_LOGGER_NAME);
    // clusterの中身を末尾に追加する
    LogFine(logger, "merging cluster");
    for (vector<BandAndPower>::const_iterator it = cluster.bandAndPowerList.begin(); it != cluster.bandAndPowerList.end(); ++it)
    {
        LogFinest(logger, format("merging band %d") % it->band.Index());
        this->bandAndPowerList.push_back(*it);
    }
}

double Cluster::CostF(const Cluster& cluster)
{
    static Logger& logger = Logger::GetLogger(Logger::GLOBAL_LOGGER_NAME);
    double cost = 0.0;

    LogFine(logger, format("this back band is %d, next front band is %d") %
            this->bandAndPowerList.back().band.Index() % cluster.bandAndPowerList.front().band.Index());
    if (cluster.bandAndPowerList.front().band.Index() - this->bandAndPowerList.back().band.Index() == 1)
    {
        cost = 0.0;
    }
    else
    {
        cost = 100.0;
    }
    return cost;
}

}
